from dataclasses import dataclass, asdict
import configparser

@dataclass(slots=True, frozen=True)
class Config:
    streamer: str
    app_id: str
    app_secret: str
    target_tg_chat: str
    tg_token: str
    check_period: int
    cleanup_msg: bool

def load_config(config_path: str = "twitch-tgbot.cfg") -> Config:
    """
    Эта функция либо читает существующий конфиг, либо создает новый.
    Возвращает объект конфига (configparser.ConfigParser())
    """
    config_file = configparser.ConfigParser()
    # Читаем конфиг, если пустой - заполняем
    if not config_file.read(config_path) or not config_file.has_section('twitch'):
        config_file.add_section('twitch')
    twitch = config_file['twitch']
    config = Config(
        streamer=twitch.get('streamer',fallback='the_viox'),
        app_id=twitch.get('app_id',fallback=''),
        app_secret=twitch.get('app_secret',fallback=''),
        target_tg_chat=twitch.get('target_tg_chat',fallback=''),
        tg_token=twitch.get('tg_token',fallback=''),
        check_period=twitch.getint('check_period',fallback=10),
        cleanup_msg=twitch.getboolean('cleanup_msg',fallback=True)
    )
    with open(config_path, 'w') as cfg_file:
        config_file.read_dict({'twitch': asdict(config)})
        config_file.write(cfg_file)
    return config